@@ -1,34 +1,6 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2011-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2011-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """Python function to register |UDM| extensions in |LDAP|."""
 
@@ -152,7 +124,8 @@ def get_handler_message(name: str, binddn: str, bindpw: str) -> dict:
         lo = udm_uldap.access(
             host=listener.configRegistry.get('ldap/master'),
             base=listener.configRegistry.get('ldap/base'),
-            binddn=binddn, bindpw=bindpw)
+            binddn=binddn, bindpw=bindpw,
+        )
         position = udm_uldap.position(lo.base)
         position_dn = 'cn=handler_messages,cn=univention,{}'.format(listener.configRegistry.get('ldap/base'))
         udm_modules.update()
@@ -217,7 +190,7 @@ class UniventionLDAPExtension(metaclass=ABCMeta):
         current_ucs_version = "%s-%s" % (ucr.get('version/version'), ucr.get('version/patchlevel'))
         if self.options.ucsversionstart and UCS_Version(current_ucs_version) < UCS_Version(self.options.ucsversionstart):
             return False
-        if self.options.ucsversionend and UCS_Version(current_ucs_version) > UCS_Version(self.options.ucsversionend):
+        if self.options.ucsversionend and UCS_Version(current_ucs_version) > UCS_Version(self.options.ucsversionend):  # noqa: SIM103
             return False
         return True  # probably yes
 
@@ -259,6 +232,7 @@ class UniventionLDAPExtension(metaclass=ABCMeta):
             lo = udm_uldap.access(
                 host=self.ucr["ldap/master"],
                 port=self.ucr["ldap/master/port"],
+                base=self.ucr['ldap/base'],
                 binddn=self.options.binddn,
                 bindpw=password,
             )
