@@ -1,40 +1,13 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2015-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2015-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 
+from __future__ import annotations
+
 import datetime
 import sys
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
-from typing import Optional  # noqa: F401
 
 import univention.uldap
 
@@ -51,12 +24,11 @@ class LicenseNotFound(LicenseCheckError):
     """The license cannot be found in LDAP"""
 
 
-def is_CSP_license(lo=None):
-    # type: (Optional[univention.uldap.acceess]) -> bool
+def is_CSP_license(lo: univention.uldap.access | None = None) -> bool:
     """
     Function to detect if installed license is a cloud service provider license (CSP).
 
-    :param univention.uldap.acceess lo: Optional |LDAP| connection to re-use. Otherwise a new |LDAP| connection with machine credentials is created.
+    :param univention.uldap.access lo: Optional |LDAP| connection to re-use. Otherwise a new |LDAP| connection with machine credentials is created.
     :returns: `True` if a valid CSP license has been found or `False` if a valid non-CSP license has been found.
     :raises LicenseNotFound: if no license was found.
     :raises LicenseExpired: if the license has expired.
