@@ -1,47 +1,17 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2012-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2012-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """Univention Common Python Library"""
 
 import subprocess
-from typing import Optional  # noqa: F401
 
 from univention.config_registry import ConfigRegistry
 from univention.lib.ucs import UCS_Version
 from univention.uldap import getMachineConnection
 
 
-def primaryVersionGreaterEqual(version):
-    # type: (str) -> bool
+def primaryVersionGreaterEqual(version: str) -> bool:
     """
     Returns True if UCS_Version of primary is greater or equal to given version.
 
@@ -51,7 +21,7 @@ def primaryVersionGreaterEqual(version):
     """
     version = UCS_Version(version)
     lo = getMachineConnection()
-    # TODO is this enough to search for the primary, or do we need cn=ucr[ldap/master]?
+    # TODO: is this enough to search for the primary, or do we need cn=ucr[ldap/master]?
     res = lo.search('univentionObjectType=computers/domaincontroller_master')
     if len(res) != 1:
         return False
@@ -62,8 +32,7 @@ def primaryVersionGreaterEqual(version):
     return primary_version >= version
 
 
-def createMachinePassword():
-    # type: () -> str
+def createMachinePassword() -> str:
     """
     Returns a $(pwgen) generated password according to the
     requirements in |UCR| variables
@@ -83,8 +52,7 @@ def createMachinePassword():
     return stdout.strip()
 
 
-def getLDAPURIs(ucr=None, sep=' '):
-    # type: (Optional[ConfigRegistry], str) -> str
+def getLDAPURIs(ucr: ConfigRegistry | None = None, sep: str = ' ') -> str:
     """
     Returns a space separated list of all configured |LDAP| servers, according to |UCR| variables
     `ldap/server/name` and `ldap/server/addition`.
@@ -114,8 +82,7 @@ def getLDAPURIs(ucr=None, sep=' '):
     return uri_string
 
 
-def getLDAPServersCommaList(ucr=None):
-    # type: (Optional[ConfigRegistry]) -> str
+def getLDAPServersCommaList(ucr: ConfigRegistry | None = None) -> str:
     """
     Returns a comma-separated string with all configured |LDAP| servers,
     `ldap/server/name` and `ldap/server/addition`.
@@ -143,8 +110,7 @@ def getLDAPServersCommaList(ucr=None):
     return ldap_servers
 
 
-def custom_username(name, ucr=None):
-    # type: (str, Optional[ConfigRegistry]) -> str
+def custom_username(name: str, ucr: ConfigRegistry | None = None) -> str:
     """
     Returns the customized user name configured via |UCR| `users/default/*`.
 
@@ -164,8 +130,7 @@ def custom_username(name, ucr=None):
     return ucr.get("users/default/" + name.lower().replace(" ", ""), name)
 
 
-def custom_groupname(name, ucr=None):
-    # type: (str, Optional[ConfigRegistry]) -> str
+def custom_groupname(name: str, ucr: ConfigRegistry | None = None) -> str:
     """
     Returns the customized group name configured via |UCR| `groups/default/*`.
 
