@@ -1,34 +1,6 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2012-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2012-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """
 Univention common Python Library for
@@ -773,8 +745,7 @@ class PackageManager:
         except SystemError as exc:
             for message in self._get_error_message(exc):
                 self.progress_state.error(message)
-            for pkg in install + remove:
-                broken.add(pkg.name)
+            broken.update(pkg.name for pkg in install + remove)
 
         # if more than one package is to be installed and this package
         #   has an OR-dependency, the package will automatically choose
