@@ -1,38 +1,10 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2017-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2017-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """
 Univention common Python library to manage
-connections to remote |UMC| servers
+connections to remote |UMC| servers.
 
 >>> umc = Client()
 >>> umc.authenticate_with_machine_account()
@@ -75,7 +47,7 @@ class _HTTPType(type):
             HTTPError.codes[mcs.code] = mcs
         except (NameError, AttributeError):
             pass
-        return type.__init__(mcs, name, bases, dict)
+        type.__init__(mcs, name, bases, dict)
 
 
 class ConnectionError(Exception):
@@ -101,7 +73,7 @@ class HTTPError(Exception, metaclass=_HTTPType):
     :param str hostname: The host name of the failed server.
     """
 
-    codes: dict[int, type['HTTPError']] = {}
+    codes: dict[int, type[Self]] = {}
     """Specialized sub-classes for individual |HTTP| error codes."""
 
     @property
@@ -144,15 +116,15 @@ class HTTPError(Exception, metaclass=_HTTPType):
         self.response = response
 
     def __repr__(self) -> str:
-        return '<HTTPError %s>' % (self,)
+        return f'<HTTPError {self}>'
 
     def __str__(self) -> str:
         traceback = ''
         data = self.response.data
         if self.status >= 500 and isinstance(self.response.data, dict) and isinstance(self.response.data.get('traceback'), str) and 'Traceback (most recent call last)' in self.response.data['traceback']:
             data = data.copy()
-            traceback = '\n%s' % (data.pop('traceback'),)
-        return '%s on %s (%s): %s%s' % (self.status, self.hostname, self.request.path, data, traceback)
+            traceback = '\n{}'.format(data.pop('traceback'))
+        return f'{self.status} on {self.hostname} ({self.request.path}): {data}{traceback}'
 
 
 class HTTPRedirect(HTTPError):
@@ -279,7 +251,7 @@ class Response:
 
     :param int status: |HTTP| status code between 200 and 599.
     :param str reason: string with the reason phrase e.g. 'OK'
-    :param str body: the raw response body
+    :param bytes body: the raw response body
     :param list headers: the response headers as list of tuples
     :param http.client.HTTPResponse _response: The original |HTTP| response.
     """
@@ -314,13 +286,13 @@ class Response:
 
     @overload
     def get_header(self, name: str) -> str | None:
-        pass
+        ...
 
     @overload
     def get_header(self, name: str, default: _T = None) -> _T:
-        pass
+        ...
 
-    def get_header(self, name: str, default: _T = None) -> None | str | _T:
+    def get_header(self, name: str, default: _T = None) -> str | _T | None:
         """
         Return original |HTTP| response header.
 
@@ -343,7 +315,7 @@ class Response:
             try:
                 data = json.loads(data.decode('UTF-8'))
             except ValueError as exc:
-                raise ConnectionError('Malformed response data: %r' % (data,), reason=exc)
+                raise ConnectionError(f'Malformed response data: {data!r}', reason=exc)
         return data
 
     @classmethod
@@ -425,7 +397,7 @@ class Client:
         :param str password: The password of the user.
 
         .. warning::
-                not implemented.
+            not implemented.
         """
         raise ConnectionError('SAML authentication currently not supported.')
 
@@ -452,10 +424,10 @@ class Client:
         :param str flavor: Optional name of the |UMC| module flavor, e.g. `users/user` for |UDM| modules.
         :param dict headers: Optional |HTTP| headers.
         :returns: The |UMC| response.
-        :rtype: Response
+        :rtype: :class:`univention.lib.umc.Response`
         """
         data = self.__build_data(options, flavor)
-        return self.request('POST', 'command/%s' % (path,), data, headers)
+        return self.request('POST', f'command/{path}', data, headers)
 
     def umc_set(self, options: dict | None, headers: dict | None = None) -> Response:
         """
@@ -464,7 +436,7 @@ class Client:
         :param dict options: The argument for the |UMC| `set` command.
         :param dict headers: Optional |HTTP| headers.
         :returns: The |UMC| response.
-        :rtype: Response
+        :rtype: :class:`univention.lib.umc.Response`
         """
         data = self.__build_data(options)
         return self.request('POST', 'set', data, headers)
@@ -477,7 +449,7 @@ class Client:
         :param dict options: The argument for the |UMC| `set` command.
         :param dict headers: Optional |HTTP| headers.
         :returns: The |UMC| response.
-        :rtype: Response
+        :rtype: :class:`univention.lib.umc.Response`
         """
         data = self.__build_data(options)
         return self.request('POST', 'set/password', data, headers)
@@ -490,7 +462,7 @@ class Client:
         :param dict options: The argument for the |UMC| `get` command.
         :param dict headers: Optional |HTTP| headers.
         :returns: The |UMC| response.
-        :rtype: Response
+        :rtype: :class:`univention.lib.umc.Response`
         """
         return self.request('POST', 'get/%s' % path, self.__build_data(options), headers)
 
@@ -499,7 +471,7 @@ class Client:
         Perform |UMC| upload action.
 
         .. warning::
-                not implemented.
+            not implemented.
         """
         raise NotImplementedError('File uploads currently need to be done manually.')
 
@@ -511,7 +483,7 @@ class Client:
         :param str password: The password of the user.
         :param data: Additional argument for the |UMC| `auth` command.
         :returns: The |UMC| response.
-        :rtype: Response
+        :rtype: :class:`univention.lib.umc.Response`
         """
         data = self.__build_data(dict({'username': username, 'password': password}, **data))
         return self.request('POST', 'auth', data)
@@ -521,7 +493,7 @@ class Client:
         Perform |UMC| logout action.
 
         :returns: The |UMC| response.
-        :rtype: Response
+        :rtype: :class:`univention.lib.umc.Response`
         """
         try:
             return self.request('GET', 'logout')
@@ -536,9 +508,12 @@ class Client:
         :param str path: The |URL| of the request.
         :param data: The message body.
         :param dict headers: Optional |HTTP| headers.
+
+        :raises :class:`univention.lib.umc.Unauthorized`: if the session expired and re-authentication was disabled.
+
         :returns: The |UMC| response.
-        :rtype: Response
-        :raises Unauthorized: if the session expired and re-authentication was disabled.
+        :rtype: :class:`univention.lib.umc.Response`
+
         """
         request = Request(method, path, data, headers)
         try:
@@ -555,7 +530,7 @@ class Client:
 
         :param Request request: A |UMC| request.
         :returns: The |UMC| response.
-        :rtype: Response
+        :rtype: :class:`univention.lib.umc.Response`
         :raises ConnectionError: if the request cannot be send.
         :raises HTTPError: if an |UMC| error occurs.
         """
@@ -577,7 +552,7 @@ class Client:
         """
         Parse cookies from |HTTP| response and store for next request.
 
-        :param http.client.HTTPResponse: The |HTTP| response.
+        :param http.client.HTTPResponse response: The |HTTP| response.
         """
         # FIXME: this cookie handling doesn't respect path, domain and expiry
         cookies: SimpleCookie[Any] = SimpleCookie()
@@ -592,7 +567,7 @@ class Client:
         :returns: The |HTTP| response.
         :rtype: http.client.HTTPResponse
         """
-        uri = '%s%s' % (self._base_uri, request.path)
+        uri = f'{self._base_uri}{request.path}'
         con = self._get_connection()
         con.request(request.method, uri, request.get_body(), headers=request.headers)
         response = con.getresponse()
